@@ -1,8 +1,18 @@
 #undef PACKAGE
 #undef VERSION
+
+#undef HAVE_LIBSM
+#undef ENABLE_NLS
+#undef HAVE_CATGETS
+#undef HAVE_GETTEXT
+#undef HAVE_LC_MESSAGES
+#undef HAVE_STPCPY
+
+
 #undef GUPPI_MAJOR_VERSION
 #undef GUPPI_MINOR_VERSION
 #undef GUPPI_MICRO_VERSION
+
 #undef HAVE_GUILE
 #undef HAVE_HISTORY
 #undef HAVE_READLINE
@@ -11,5 +21,6 @@
 #undef HAVE_LIBSM
 #undef HAVE_GUILE_GTK
 #undef HAVE_GUILE_GNOME
+#undef USING_BONOBO
 
 
