@@ -40,7 +40,10 @@ CORBA_Environment* guppi_corba_env(void);
 const gchar* guppi_guile_ior(void);
 
 // Init things
-void guppi_corba_init(int* argc, char** argv);
+void guppi_corba_init(int* argc, char** argv,
+		      const struct poptOption* options,
+		      gint popt_flags,
+		      poptContext* return_ctx);
 // Un-init things
 void guppi_corba_shutdown(gpointer dummy);
 
