@@ -1,5 +1,4 @@
-/* This is -*- C++ -*- */
-/* $Id: file-open.h,v 1.1 1999/12/06 05:19:43 trow Exp $ */
+/* $Id: file-open.h,v 1.3 2000/04/13 19:45:18 trow Exp $ */
 
 /*
  * file-open.h
@@ -31,9 +30,18 @@
 #include <config.h>
 #include <gnome.h>
 
-void file_open(void);
+#include "guppi-app.h"
+
+void file_open(GtkWidget*, GuppiApp*);
+
+#define DEFAULT_FILE_OPEN_THRESHOLD 0.0
+
+void file_open_ask_about_import_type(const gchar* filename,
+				     gboolean force_ask,
+				     double threshold,
+				     GuppiApp*);
 
 
 #endif /* _INC_FILE_OPEN_H */
 
-/* $Id: file-open.h,v 1.1 1999/12/06 05:19:43 trow Exp $ */
+/* $Id: file-open.h,v 1.3 2000/04/13 19:45:18 trow Exp $ */
