@@ -1,4 +1,4 @@
-/* $Id: guppi.c,v 1.21 2000/04/13 01:01:45 trow Exp $ */
+/* $Id: guppi.c,v 1.23 2000/05/01 04:41:37 trow Exp $ */
 
 /*
  * guppi.c
@@ -36,6 +36,9 @@
 #include <guppi-stat-init.h>
 #include <guppi-plot-init.h>
 #include <guppi-plot-plug-in.h>
+#ifdef USING_BONOBO
+#include <guppi-bonobo.h>
+#endif
 #include "app_scm.h"
 #include "term.h"
 #include "file-open.h"
@@ -141,6 +144,17 @@ abort_signal_handler(gint x)
 static void
 real_main(void* closure, int argc, char* argv[])
 {
+  gchar* opt_script_filename = NULL;
+  gint opt_batch_flag = 0;
+  struct poptOption options[] = {
+    { "script", 's', POPT_ARG_STRING, &opt_script_filename, 0, 
+      N_("Load and evaluate code from FILENAME"), N_("FILENAME") },
+    { "batch", 'b', POPT_ARG_NONE, &opt_batch_flag, 0,
+      N_("Run in batch mode"), NULL },
+    { NULL, '\0', 0, NULL, 0, NULL, NULL }
+  };
+  poptContext pctx;
+  
   struct sigaction xsh, ash;
 
   /* Trap ctrl-c from the starting console */
@@ -154,26 +168,29 @@ real_main(void* closure, int argc, char* argv[])
   sigaction(SIGINT, &xsh, NULL);
   sigaction(SIGHUP, &ash, NULL);
 
-  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-  textdomain(PACKAGE);
+  if (!opt_batch_flag)
+    guppi_splash_create();
 
-  guppi_make_warnings_and_criticals_stop_in_debugger("libguppiscatter", NULL);
-
-  /* We have many, many libraries and misc. things to initialize */
-  guppi_splash_message(_("Initializing libglade"));
-  glade_gnome_init();
-  
   /*
     guppi_corba_init() calls gnome_CORBA_init(), which in turn calls
     gnome_init().
   */
   guppi_splash_message(_("Initializing CORBA"));
-  guppi_corba_init(&argc, argv);
+  guppi_corba_init(&argc, argv, options, 0, &pctx);
   guppi_exit_connect_shutdown_func(guppi_corba_shutdown, NULL);
 
+  /* We have many, many libraries and misc. things to initialize */
+  guppi_splash_message(_("Initializing libglade"));
+  glade_gnome_init();
+  
   guppi_splash_message(_("Initializing Utility Library"));
   guppi_useful_init();
 
+#ifdef USING_BONOBO
+  guppi_splash_message(_("Initializing Bonobo"));
+  guppi_bonobo_init();
+#endif
+
   guppi_splash_message(_("Initializing Statistics Library"));
   guppi_stat_init();
 
@@ -189,8 +206,10 @@ real_main(void* closure, int argc, char* argv[])
   guppi_splash_message(_("Loading Plug-Ins"));
   guppi_plug_in_load_all();
 
-  guppi_splash_message(_("Building Main Guppi Window"));
-  guppi_app = GNOME_APP(guppi_app_new());
+  if (!opt_batch_flag) {
+    guppi_splash_message(_("Building Main Guppi Window"));
+    guppi_app = GNOME_APP(guppi_app_new());
+  }
 
   /* We load our rc files after building our app window so that we can
      freely monkey with the app's UI. */
@@ -198,8 +217,16 @@ real_main(void* closure, int argc, char* argv[])
 
   guppi_splash_destroy();
 
-  gtk_widget_show_all(GTK_WIDGET(guppi_app));
-  gtk_main();
+  if (opt_script_filename != NULL) {
+    g_message("script filename: %s", opt_script_filename);
+  }
+
+  if (opt_batch_flag) {
+    guppi_exit();
+  } else {
+    gtk_widget_show_all(GTK_WIDGET(guppi_app));
+    gtk_main();
+  }
 }
 
 int
@@ -212,13 +239,15 @@ main(int argc, char* argv[])
   gtk_init(&argc, &argv);
   gdk_imlib_init();
 
-  guppi_splash_create();
+  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
+  textdomain(PACKAGE);
+
+  g_message(_("Booting Guile"));
 
-  guppi_splash_message(_("Booting Guile"));
   scm_boot_guile(argc, argv, real_main, NULL);
   g_assert_not_reached();
   return 1;
 }
 
 
-/* $Id: guppi.c,v 1.21 2000/04/13 01:01:45 trow Exp $ */
+/* $Id: guppi.c,v 1.23 2000/05/01 04:41:37 trow Exp $ */
