@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data.c,v 1.6 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data.c,v 1.7 2000/04/21 23:22:44 trow Exp $ */
 
 /*
  * guppi-data.c
@@ -187,6 +187,20 @@ guppi_data_impl(GuppiData* gd)
   return gd->impl;
 }
 
+GuppiDataImplClass*
+guppi_data_impl_class(GuppiData* gd)
+{
+  GuppiDataImpl* impl;
+
+  g_return_val_if_fail(gd != NULL, NULL);
+
+  impl = guppi_data_impl(gd);
+  if (impl == NULL)
+    return NULL;
+
+  return GUPPI_DATA_IMPL_CLASS(GTK_OBJECT(impl)->klass);
+}
+
 const gchar*
 guppi_data_get_label(const GuppiData* gd)
 {
@@ -422,4 +436,4 @@ guppi_data_add_subdata(GuppiData* data, GuppiData* subdata)
 }
 
 
-/* $Id: guppi-data.c,v 1.6 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data.c,v 1.7 2000/04/21 23:22:44 trow Exp $ */
