@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.4 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.5 2000/04/21 23:22:44 trow Exp $ */
 
 /*
  * guppi-seq-boolean-core-impl.c
@@ -64,8 +64,16 @@ guppi_seq_boolean_core_impl_destroy(GtkObject* obj)
 static void
 guppi_seq_boolean_core_impl_finalize(GtkObject* obj)
 {
+  GuppiSeqBooleanCoreImpl* impl = GUPPI_SEQ_BOOLEAN_CORE_IMPL(obj);
+
   if (parent_class->finalize)
     parent_class->finalize(obj);
+
+  if (impl->garray) {
+    gtk_object_unref(GTK_OBJECT(impl->garray));
+    impl->garray = NULL;
+  }
+
 }
 
 /*****************************************************************************/
@@ -655,4 +663,4 @@ guppi_seq_boolean_core_impl_new(void)
 
 
 
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.4 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.5 2000/04/21 23:22:44 trow Exp $ */
