@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-scalar-impl.h,v 1.3 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-scalar-impl.h,v 1.4 2000/05/03 17:06:51 trow Exp $ */
 
 /*
  * guppi-seq-scalar-impl.h
@@ -49,6 +49,8 @@ struct _GuppiSeqScalarImplClass {
   void (*range)(const GuppiSeqScalarImpl*, double* min, double* max);
   double (*sum)(const GuppiSeqScalarImpl*);
   double (*var)(const GuppiSeqScalarImpl*);
+  void (*quartiles)(const GuppiSeqScalarImpl*,
+		    double* q1, double* med, double* q3);
   
   double (*get)(const GuppiSeqScalarImpl*, gint);
   void (*set)(GuppiSeqScalarImpl*, gint, double);
@@ -77,4 +79,4 @@ GtkObject* guppi_seq_scalar_impl_new(void);
 
 #endif /* _INC_GUPPI_SEQ_SCALAR_IMPL_H */
 
-/* $Id: guppi-seq-scalar-impl.h,v 1.3 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-seq-scalar-impl.h,v 1.4 2000/05/03 17:06:51 trow Exp $ */
