@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-scalar.c,v 1.4 2000/03/04 18:51:36 trow Exp $ */
+/* $Id: guppi-seq-scalar.c,v 1.5 2000/05/03 17:06:51 trow Exp $ */
 
 /*
  * guppi-seq-scalar.c
@@ -533,6 +533,69 @@ guppi_seq_scalar_sdevs(const GuppiSeqScalar* seq)
   return sqrt(v);
 }
 
+double
+guppi_seq_scalar_q1(const GuppiSeqScalar* seq)
+{
+  const GuppiSeqScalarImpl* impl;
+  GuppiSeqScalarImplClass* impl_class;
+
+  g_return_val_if_fail(seq != NULL, 0);
+
+  impl = GUPPI_SEQ_SCALAR_IMPL(guppi_data_impl(GUPPI_DATA(seq)));
+  impl_class = GUPPI_SEQ_SCALAR_IMPL_CLASS(GTK_OBJECT(impl)->klass);
+
+  if (impl_class->quartiles) {
+    double q;
+    (impl_class->quartiles)(impl, &q, NULL, NULL);
+    return q;
+  }
+
+  g_assert_not_reached();
+  return 0;
+}
+
+double
+guppi_seq_scalar_median(const GuppiSeqScalar* seq)
+{
+  const GuppiSeqScalarImpl* impl;
+  GuppiSeqScalarImplClass* impl_class;
+
+  g_return_val_if_fail(seq != NULL, 0);
+
+  impl = GUPPI_SEQ_SCALAR_IMPL(guppi_data_impl(GUPPI_DATA(seq)));
+  impl_class = GUPPI_SEQ_SCALAR_IMPL_CLASS(GTK_OBJECT(impl)->klass);
+
+  if (impl_class->quartiles) {
+    double m;
+    (impl_class->quartiles)(impl, NULL, &m, NULL);
+    return m;
+  }
+
+  g_assert_not_reached();
+  return 0;
+}
+
+double
+guppi_seq_scalar_q3(const GuppiSeqScalar* seq)
+{
+  const GuppiSeqScalarImpl* impl;
+  GuppiSeqScalarImplClass* impl_class;
+
+  g_return_val_if_fail(seq != NULL, 0);
+
+  impl = GUPPI_SEQ_SCALAR_IMPL(guppi_data_impl(GUPPI_DATA(seq)));
+  impl_class = GUPPI_SEQ_SCALAR_IMPL_CLASS(GTK_OBJECT(impl)->klass);
+
+  if (impl_class->quartiles) {
+    double q;
+    (impl_class->quartiles)(impl, NULL, NULL, &q);
+    return q;
+  }
+
+  g_assert_not_reached();
+  return 0;
+}
+
 gconstpointer
 guppi_seq_scalar_raw(const GuppiSeqScalar* seq, gint* stride)
 {
@@ -551,4 +614,4 @@ guppi_seq_scalar_raw(const GuppiSeqScalar* seq, gint* stride)
   return (impl_class->raw_access)(impl, stride);
 }
 
-/* $Id: guppi-seq-scalar.c,v 1.4 2000/03/04 18:51:36 trow Exp $ */
+/* $Id: guppi-seq-scalar.c,v 1.5 2000/05/03 17:06:51 trow Exp $ */
