@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-scalar.h,v 1.4 2000/03/04 18:50:49 trow Exp $ */
+/* $Id: guppi-seq-scalar.h,v 1.5 2000/05/03 17:06:51 trow Exp $ */
 
 /*
  * guppi-seq-scalar.h
@@ -83,6 +83,9 @@ double guppi_seq_scalar_var(const GuppiSeqScalar*);
 double guppi_seq_scalar_vars(const GuppiSeqScalar*);
 double guppi_seq_scalar_sdev(const GuppiSeqScalar*);
 double guppi_seq_scalar_sdevs(const GuppiSeqScalar*);
+double guppi_seq_scalar_q1(const GuppiSeqScalar*);
+double guppi_seq_scalar_median(const GuppiSeqScalar*);
+double guppi_seq_scalar_q3(const GuppiSeqScalar*);
 
 gconstpointer guppi_seq_scalar_raw(const GuppiSeqScalar*, gint* stride);
 
@@ -92,4 +95,4 @@ gconstpointer guppi_seq_scalar_raw(const GuppiSeqScalar*, gint* stride);
 
 #endif /* _INC_GUPPI_SEQ_SCALAR_H */
 
-/* $Id: guppi-seq-scalar.h,v 1.4 2000/03/04 18:50:49 trow Exp $ */
+/* $Id: guppi-seq-scalar.h,v 1.5 2000/05/03 17:06:51 trow Exp $ */
