@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-tree-view.c,v 1.3 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data-tree-view.c,v 1.4 2000/04/25 13:57:07 trow Exp $ */
 
 /*
  * guppi-data-tree-view.c
@@ -186,13 +186,17 @@ void
 guppi_data_tree_view_construct(GuppiDataTreeView* tv,
 			       GuppiDataTree* tree)
 {
-  gchar* titles[] = { N_("Data"),
-		      N_("Type"),
-		      N_("Size"),
-		      N_("Mem") };
+  static gchar* titles[4] = { NULL };
   gint column_count = 4;
   gint i;
 
+  if (titles[0] == NULL) {
+    titles[0] = _("Data");
+    titles[1] = _("Type");
+    titles[2] = _("Size");
+    titles[3] = _("Mem");
+  }
+
 
   g_return_if_fail(tv != NULL);
   g_return_if_fail(tree != NULL);
@@ -243,4 +247,4 @@ guppi_data_tree_view_popup(GuppiDataTree* tree)
 
 
 
-/* $Id: guppi-data-tree-view.c,v 1.3 2000/04/13 19:45:19 trow Exp $ */
+/* $Id: guppi-data-tree-view.c,v 1.4 2000/04/25 13:57:07 trow Exp $ */
