@@ -1,4 +1,4 @@
-/* $Id: guppi-canvas-item.c,v 1.15 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.18 2000/05/01 04:41:38 trow Exp $ */
 
 /*
  * guppi-canvas-item.c
@@ -29,6 +29,7 @@
 #include "guppi-canvas-item.h"
 
 enum {
+  CHANGED_GEOMETRY,
   RESCALED_X,
   RESCALED_Y,
   REBOUNDED_X,
@@ -118,7 +119,13 @@ guppi_canvas_item_destroy(GtkObject* obj)
 static void
 guppi_canvas_item_finalize(GtkObject* obj)
 {
+  GuppiCanvasItem* gci = GUPPI_CANVAS_ITEM(obj);
 
+  g_free(gci->x_transform);
+  gci->x_transform = NULL;
+
+  g_free(gci->y_transform);
+  gci->y_transform = NULL;
 }
 
 
@@ -217,6 +224,15 @@ guppi_canvas_item_class_init(GuppiCanvasItemClass* klass)
   item_class = GNOME_CANVAS_ITEM_CLASS(klass);
   parent_class = gtk_type_class(GNOME_TYPE_CANVAS_ITEM);
 
+  gci_signals[CHANGED_GEOMETRY] = 
+    gtk_signal_new("changed_geometry",
+		   GTK_RUN_FIRST,
+		   object_class->type,
+		   GTK_SIGNAL_OFFSET(GuppiCanvasItemClass,
+				     changed_geometry),
+		   gtk_marshal_NONE__NONE,
+		   GTK_TYPE_NONE, 0);
+
   gci_signals[RESCALED_X] =
     gtk_signal_new("rescaled_x",
 		   GTK_RUN_FIRST,
@@ -324,6 +340,11 @@ guppi_canvas_item_class_init(GuppiCanvasItemClass* klass)
 static void
 guppi_canvas_item_init(GuppiCanvasItem* gci)
 {
+  gci->min_width = gci->min_height = 0;
+  gci->optimal_width = gci->optimal_height = 0;
+  gci->max_width = gci->max_height = 0;
+  gci->width_hunger = gci->height_hunger = 1;
+
   gci->x_transform  = transform_new();
   gci->y_transform  = transform_new();
 
@@ -371,6 +392,81 @@ guppi_canvas_item_get_type(void)
 
 /*****************************************************************************/
 
+void
+guppi_canvas_item_set_geometry(GuppiCanvasItem* gci,
+			       double w0, double w, double w1, double whung,
+			       double h0, double h, double h1, double hhung)
+{
+  g_return_if_fail(gci != NULL);
+
+  w0 = MAX(w0, 0);
+  w = MAX(w, 0);
+  w1 = MAX(w1, 0);
+  whung = MAX(whung, 0);
+  h0 = MAX(h0, 0);
+  h = MAX(h, 0);
+  h1 = MAX(h1, 0);
+  hhung = MAX(hhung, 0);
+
+  if (gci->min_width != w0 ||
+      gci->optimal_width != w ||
+      gci->max_width != w1 ||
+      gci->width_hunger != whung ||
+      gci->min_height != h0 ||
+      gci->optimal_height != h ||
+      gci->max_height != h1 ||
+      gci->height_hunger != hhung) {
+
+    gci->changed_geometry = TRUE;
+
+    gci->min_width = w0;
+    gci->optimal_width = w;
+    gci->max_width = w1;
+    gci->width_hunger = whung;
+
+    gci->min_height = h0;
+    gci->optimal_height = h;
+    gci->max_height = h1;
+    gci->height_hunger = hhung;
+
+    if (!gci->block_changed_geometry_signals)
+      gtk_signal_emit(GTK_OBJECT(gci), gci_signals[CHANGED_GEOMETRY]);
+  }
+}
+
+void
+guppi_canvas_item_calc_geometry(GuppiCanvasItem* gci)
+{
+  GuppiCanvasItemClass* klass;
+  
+  g_return_if_fail(gci != NULL);
+
+  if (!gci->need_geometry_recalc)
+    return;
+
+  klass = GUPPI_CANVAS_ITEM_CLASS(GTK_OBJECT(gci)->klass);
+
+  if (klass->calc_geometry)
+    (klass->calc_geometry)(gci);
+
+  gci->need_geometry_recalc = FALSE;
+}
+
+static gint
+idle_calc_geom_cb(gpointer foo)
+{
+  if (foo != NULL)
+    guppi_canvas_item_calc_geometry(GUPPI_CANVAS_ITEM(foo));
+  return FALSE;
+}
+
+void
+guppi_canvas_item_calc_geometry_when_idle(GuppiCanvasItem* gci)
+{
+  g_return_if_fail(gci != NULL);
+  gtk_idle_add(idle_calc_geom_cb, gci);
+}
+
 GuppiItemState*
 guppi_canvas_item_state(GuppiCanvasItem* gci)
 {
@@ -957,6 +1053,36 @@ guppi_canvas_item_disconnect(GuppiCanvasItem* a, GuppiCanvasItem* b)
 
 }
 
-/* $Id: guppi-canvas-item.c,v 1.15 2000/04/13 19:45:20 trow Exp $ */
+/****************************************************************************/
+
+GnomeCanvasBuf*
+guppi_canvas_item_clip_buf(GuppiCanvasItem* gci, GnomeCanvasBuf* buf)
+{
+  GnomeCanvasBuf* my_buf;
+
+  g_return_val_if_fail(gci != NULL, NULL);
+  g_return_val_if_fail(buf != NULL, NULL);
+
+  my_buf = g_new0(GnomeCanvasBuf, 1);
+
+  my_buf->buf_rowstride = buf->buf_rowstride;
+
+  my_buf->rect.x0 = MAX(buf->rect.x0, gci->cx0);
+  my_buf->rect.x1 = MIN(buf->rect.x1, gci->cx1);
+  my_buf->rect.y0 = MAX(buf->rect.y0, gci->cy0);
+  my_buf->rect.y1 = MIN(buf->rect.y1, gci->cy1);
+
+  my_buf->bg_color = buf->bg_color;
+  my_buf->is_bg = buf->is_bg;
+  my_buf->is_buf = buf->is_buf;
+
+  my_buf->buf = buf->buf;
+  my_buf->buf += 3*(my_buf->rect.x0 - buf->rect.x0);
+  my_buf->buf += buf->buf_rowstride*(my_buf->rect.y0 - buf->rect.y0);
+
+  return my_buf;
+}
+
+/* $Id: guppi-canvas-item.c,v 1.18 2000/05/01 04:41:38 trow Exp $ */
 
 
