@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.h,v 1.11 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.14 2000/05/01 04:41:38 trow Exp $ */
 
 /*
  * guppi-canvas-item.h
@@ -39,6 +39,13 @@ typedef struct _GuppiCanvasItemClass GuppiCanvasItemClass;
 struct _GuppiCanvasItem {
   GnomeCanvasItem canvas_item;
 
+  gboolean need_geometry_recalc, changed_geometry;
+  double min_width, min_height;
+  double optimal_width, optimal_height;
+  double max_width, max_height;
+  double width_hunger, height_hunger;
+  gboolean block_changed_geometry_signals;
+
   /* Bounding box of object in world & canvas coordinates. */
   double wx0, wy0, wx1, wy1;
   gint cx0, cy0, cx1, cy1;
@@ -73,16 +80,18 @@ struct _GuppiCanvasItemClass {
   /* virtual functions */
   void (*state_set_hook)(GuppiCanvasItem*, GuppiItemState*);
   void (*state_unset_hook)(GuppiCanvasItem*);
+  void (*calc_geometry)(GuppiCanvasItem*);
 
   /* signal functions */
-  void (*rescaled_x)(GnomeCanvasItem*, double x0, double x1);
-  void (*rescaled_y)(GnomeCanvasItem*, double y0, double y1);
-  void (*rebounded_x)(GnomeCanvasItem*, double x0, double x1);
-  void (*rebounded_y)(GnomeCanvasItem*, double y0, double y1);
-  void (*renegotiate_x_start)(GnomeCanvasItem*);
-  void (*renegotiate_x_declare)(GnomeCanvasItem*, double, double);
-  void (*renegotiate_y_start)(GnomeCanvasItem*);
-  void (*renegotiate_y_declare)(GnomeCanvasItem*, double, double);
+  void (*changed_geometry)(GuppiCanvasItem*);
+  void (*rescaled_x)(GuppiCanvasItem*, double x0, double x1);
+  void (*rescaled_y)(GuppiCanvasItem*, double y0, double y1);
+  void (*rebounded_x)(GuppiCanvasItem*, double x0, double x1);
+  void (*rebounded_y)(GuppiCanvasItem*, double y0, double y1);
+  void (*renegotiate_x_start)(GuppiCanvasItem*);
+  void (*renegotiate_x_declare)(GuppiCanvasItem*, double, double);
+  void (*renegotiate_y_start)(GuppiCanvasItem*);
+  void (*renegotiate_y_declare)(GuppiCanvasItem*, double, double);
 };
 
 #define GUPPI_TYPE_CANVAS_ITEM (guppi_canvas_item_get_type())
@@ -99,6 +108,14 @@ struct _GuppiCanvasItemClass {
 
 GtkType guppi_canvas_item_get_type(void);
 
+void guppi_canvas_item_set_geometry(GuppiCanvasItem*,
+				    double w0, double w, double w1,
+				    double whung,
+				    double h0, double h, double h1, 
+				    double hhung);
+void guppi_canvas_item_calc_geometry(GuppiCanvasItem*);
+void guppi_canvas_item_calc_geometry_when_idle(GuppiCanvasItem*);
+
 GuppiItemState* guppi_canvas_item_state(GuppiCanvasItem*);
 void guppi_canvas_item_set_state(GuppiCanvasItem*, GuppiItemState*);
 
@@ -160,6 +177,8 @@ void guppi_canvas_item_connect_y_scales(GuppiCanvasItem*, GuppiCanvasItem*);
 void guppi_canvas_item_connect_scales(GuppiCanvasItem*, GuppiCanvasItem*);
 void guppi_canvas_item_disconnect(GuppiCanvasItem*, GuppiCanvasItem*);
 
+GnomeCanvasBuf* guppi_canvas_item_clip_buf(GuppiCanvasItem*, GnomeCanvasBuf*);
+
 #endif /* _INC_GUPPI_CANVAS_ITEM_H */
 
-/* $Id: guppi-canvas-item.h,v 1.11 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.14 2000/05/01 04:41:38 trow Exp $ */
