@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-state.c,v 1.9 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-plot-state.c,v 1.11 2000/05/03 17:06:51 trow Exp $ */
 
 /*
  * guppi-plot-state.c
@@ -25,6 +25,7 @@
  * USA
  */
 
+#include "guppi-layout-grid.h"
 #include "guppi-plot-state.h"
 
 static GtkObjectClass* parent_class = NULL;
@@ -180,6 +181,18 @@ guppi_plot_state_add_element(GuppiPlotState* gps, GuppiPlotElement* element)
   gtk_signal_emit(GTK_OBJECT(gps), gps_signals[ADD], element);
 }
 
+void
+guppi_plot_state_add_element_at(GuppiPlotState* gps,
+				GuppiPlotElement* element,
+				gint gridpos_x, gint gridpos_y)
+{
+  g_return_if_fail(gps != NULL);
+  g_return_if_fail(element != NULL);
+
+  guppi_plot_element_set_gridpos(element, gridpos_x, gridpos_y);
+  guppi_plot_state_add_element(gps, element);
+}
+
 void
 guppi_plot_state_remove_element(GuppiPlotState* gps, GuppiPlotElement* element)
 {
@@ -248,35 +261,44 @@ item_raise_lower_cb(GuppiPlotElement* e, gint n, gpointer data)
 void
 guppi_plot_state_render(GuppiPlotState* gps, GnomeCanvas* canvas)
 {
-  gint i;
+  gint i, N, x0=0, x1=0, y0=0, y1=0;
   GuppiPlotElement* e;
   GuppiCanvasItem* ci;
-  GuppiCanvasItem* first_ci = NULL;
+  GuppiLayoutGrid* grid;
+  GuppiLayoutGridCell* cell;
 
   g_return_if_fail(gps != NULL);
   g_return_if_fail(canvas != NULL);
 
+  N = guppi_plot_state_element_count(gps);
+
   /* Some hard-wired canvas info for now */
   gtk_widget_set_usize(GTK_WIDGET(canvas), 500, 400);
   gnome_canvas_set_scroll_region(canvas, 0, 0, 500, 400);
 
-  /* We store stuff top to bottom, so we have to render "backwards" 
-     to get the stacking in the right order. */
-  i = guppi_plot_state_element_count(gps);
-  while (i>0) {
-    --i;
+  /* Find x,y gridpos bounds */
+  for (i=0; i<N; ++i) {
+    e = guppi_plot_state_get_element(gps, i);
+    x0 = i ? MIN(x0, e->gridpos_x) : e->gridpos_x;
+    y0 = i ? MIN(y0, e->gridpos_y) : e->gridpos_y;
+    x1 = i ? MAX(x1, e->gridpos_x) : e->gridpos_x;
+    y1 = i ? MAX(y1, e->gridpos_y) : e->gridpos_y;
+  }
+  
+  /* Build our grid */
+  grid = guppi_layout_grid_new();
+  guppi_layout_grid_set_size(grid, x1-x0+1, y1-y0+1);
+  guppi_layout_grid_connect_to_canvas(grid, canvas);
+  
+  /* Make our canvas items, put them in our grid. */
+  for (i=0; i<N; ++i) {
     e = guppi_plot_state_get_element(gps, i);
     ci = guppi_plot_element_make_canvas_item(e, canvas, 0, 0, 100, 100);
 
-    /* Automatically connect all items.  This is a hack. */
-    if (first_ci == NULL)
-      first_ci = ci;
-    else {
-      guppi_canvas_item_connect_scales(first_ci, ci);
-      guppi_item_state_connect_x_data(first_ci->state, ci->state);
-      guppi_item_state_connect_y_data(first_ci->state, ci->state);
-    }
-
+    cell = guppi_layout_grid_get_cell(grid, e->gridpos_x-x0, e->gridpos_y-y0);
+    guppi_layout_grid_cell_add_item(cell, ci);
+  
+    
     gtk_signal_connect_object(GTK_OBJECT(e),
 			      "destroy",
 			      GTK_SIGNAL_FUNC(gtk_object_destroy),
@@ -307,7 +329,8 @@ guppi_plot_state_render(GuppiPlotState* gps, GnomeCanvas* canvas)
     else
       gnome_canvas_item_hide(GNOME_CANVAS_ITEM(ci));
   }
-  
+
+  guppi_layout_grid_connect_items_gridwise(grid);
 
 }
 
@@ -322,4 +345,4 @@ guppi_plot_state_view(GuppiPlotState* state)
 }
 
 
-/* $Id: guppi-plot-state.c,v 1.9 2000/04/13 19:45:20 trow Exp $ */
+/* $Id: guppi-plot-state.c,v 1.11 2000/05/03 17:06:51 trow Exp $ */
