@@ -1,4 +1,4 @@
-/* $Id: guppi-debug.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.2 2000/04/06 23:27:32 trow Exp $ */
 
 /*
  * guppi-debug.h
@@ -38,8 +38,16 @@ void _guppi_unimplemented_function_dialog(const gchar* function,
 					  gint line);
 
 
+#define GUPPI_ENTER _guppi_track_entry(__FILE__, __PRETTY_FUNCTION__);
+#define GUPPI_EXIT _guppi_track_exit(__FILE__, __PRETTY_FUNCTION__);
 
+void _guppi_track_entry(const gchar* function, const gchar* filename);
+void _guppi_track_exit(const gchar* function, const gchar* filename);
+
+
+void guppi_stop_in_debugger(void);
+void guppi_make_warnings_and_criticals_stop_in_debugger(const char* first_domain, ...);
 
 #endif /* _INC_GUPPI_DEBUG_H */
 
-/* $Id: guppi-debug.h,v 1.1 2000/01/17 05:44:56 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.2 2000/04/06 23:27:32 trow Exp $ */
