@@ -734,6 +734,125 @@ scm_fn_color_p(SCM x)
   return gh_bool2scm(scm_color_p(x));
 }
 
+GtkArg*
+scm2gtk_arg(SCM name, SCM x)
+{
+  GtkArg* arg = NULL;
+
+  g_return_val_if_fail(gh_string_p(name) || gh_symbol_p(name), NULL);
+
+  if (gh_boolean_p(x)) {
+    arg = gtk_arg_new(GTK_TYPE_BOOL);
+    GTK_VALUE_BOOL(*arg) = gh_scm2bool(x);
+  } else if (gh_exact_p(x)) {
+    arg = gtk_arg_new(GTK_TYPE_INT);
+    GTK_VALUE_INT(*arg) = gh_scm2int(x);
+  } else if (gh_number_p(x)) {
+    arg = gtk_arg_new(GTK_TYPE_DOUBLE);
+    GTK_VALUE_DOUBLE(*arg) = gh_scm2double(x);
+  } else if (gh_string_p(x)) {
+    arg = gtk_arg_new(GTK_TYPE_STRING);
+    GTK_VALUE_STRING(*arg) = gh_scm2newstr(x, NULL);
+  }
+
+  g_return_val_if_fail(arg != NULL, NULL);
+  
+  arg->name = gh_string_p(name) ?
+    gh_scm2newstr(name, NULL) : gh_symbol2newstr(name, NULL);
+
+  return arg;
+}
+
+SCM
+gtk_arg2scm(GtkArg* x)
+{
+  g_return_val_if_fail(x != NULL, SCM_UNDEFINED);
+  
+  switch (GTK_FUNDAMENTAL_TYPE(x->type)) {
+  case GTK_TYPE_CHAR:
+    return gh_char2scm(GTK_VALUE_CHAR(*x));
+  case GTK_TYPE_UCHAR:
+    return gh_char2scm((char)GTK_VALUE_UCHAR(*x));
+  case GTK_TYPE_BOOL:
+    return gh_bool2scm(GTK_VALUE_BOOL(*x));
+  case GTK_TYPE_INT:
+    return gh_int2scm(GTK_VALUE_INT(*x));
+  case GTK_TYPE_UINT:
+    return gh_ulong2scm(GTK_VALUE_UINT(*x));
+  case GTK_TYPE_FLOAT:
+    return gh_double2scm((double)GTK_VALUE_FLOAT(*x));
+  case GTK_TYPE_DOUBLE:
+    return gh_double2scm(GTK_VALUE_DOUBLE(*x));
+  case GTK_TYPE_STRING:
+    return gh_str02scm(GTK_VALUE_STRING(*x));
+  default:
+    return SCM_UNDEFINED;
+  }
+}
+
+GtkArg*
+scm2argv(SCM list, guint* N)
+{
+  SCM name, val, iter;
+  guint len=0, i;
+  GtkArg* args;
+  GtkArg* this_arg;
+
+  g_return_val_if_fail(N != NULL, NULL);
+  g_return_val_if_fail(gh_list_p(list), NULL);
+
+  if (gh_null_p(list)) {
+    *N = 0;
+    return NULL;
+  }
+
+  /* Count list length */
+  iter = list;
+  while (!gh_null_p(iter)) {
+    ++len;
+    iter = gh_cdr(iter);
+  }
+  g_assert(len % 2 == 0);
+  len /= 2;
+
+  args = g_new0(GtkArg, len);
+  *N = len;
+
+  i=0;
+  iter = list;
+  while (!gh_null_p(iter)) {
+    name = gh_car(iter);
+    iter = gh_cdr(iter);
+    val = gh_car(iter);
+    iter = gh_cdr(iter);
+    this_arg = scm2gtk_arg(name, val);
+
+    gtk_arg_copy(this_arg, &args[i]);
+    args[i].name = this_arg->name;
+    this_arg->name = NULL;
+    gtk_arg_free(this_arg, TRUE);
+  }
+
+  return args;
+}
+
+void
+guppi_argv_free(GtkArg* args, guint N)
+{
+  guint i;
+
+  if (args == NULL || N == 0)
+    return;
+ 
+  for (i=0; i<N; ++i) {
+    g_free(args[i].name);
+    if (GTK_FUNDAMENTAL_TYPE(args[i].type) == GTK_TYPE_STRING)
+      g_free(GTK_VALUE_STRING(args[i]));
+  }
+  g_free(args);
+}
+
+
 /****************************************************************************/
 
 void 
