@@ -1,4 +1,4 @@
-/* $Id: guppi-guile.h,v 1.3 2000/02/10 02:07:03 trow Exp $ */
+/* $Id: guppi-guile.h,v 1.4 2000/04/21 23:22:45 trow Exp $ */
 
 /* 
  * guppi-guile.h
@@ -28,7 +28,7 @@
 #define _INC_GUPPI_GUILE_H
 
 #include <config.h>
-#include <glib.h>
+#include <gnome.h>
 #include <stdlib.h>
 #include <libguile.h>
 #include <guile/gh.h>
@@ -103,7 +103,11 @@ gboolean scm_color_p(SCM);
 SCM color2scm(guint32);
 guint32 scm2color(SCM);
 
+GtkArg* scm2gtk_arg(SCM name, SCM);
+SCM gtk_arg2scm(GtkArg*);
+GtkArg* scm2argv(SCM list, guint* length);
+void guppi_argv_free(GtkArg*, guint len);
 
 #endif /* _INC_GUPPI_GUILE_H */
 
-/* $Id: guppi-guile.h,v 1.3 2000/02/10 02:07:03 trow Exp $ */
+/* $Id: guppi-guile.h,v 1.4 2000/04/21 23:22:45 trow Exp $ */
