@@ -1,4 +1,4 @@
-/* $Id: guppi-paths.c,v 1.5 2000/04/06 23:27:32 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.6 2000/04/25 13:57:11 trow Exp $ */
 
 /*
  * guppi-paths.c
@@ -207,7 +207,7 @@ gnome_guile_repl_path(void)
   }
   
   if (path == NULL) 
-    gtk_widget_show_all(gnome_error_dialog(_("\"gnome-guile-repl\" is not in your $PATH.\nWithout it, you cannot access the guile terminal.")));
+    gtk_widget_show_all(gnome_error_dialog(_("The program \"gnome-guile-repl\" is not in your $PATH.\nWithout it, you cannot access the guile terminal.")));
   
   return path;
 }
@@ -215,4 +215,4 @@ gnome_guile_repl_path(void)
 
 
 
-/* $Id: guppi-paths.c,v 1.5 2000/04/06 23:27:32 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.6 2000/04/25 13:57:11 trow Exp $ */
