@@ -1,4 +1,4 @@
-/* $Id: guppi-paths.h,v 1.2 2000/01/17 21:38:34 trow Exp $ */
+/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */
 
 /*
  * guppi-paths.h
@@ -31,9 +31,9 @@
 #include <gnome.h>
 
 const gchar* guppi_logo_graphic_path(void);
-gchar* guppi_glade_path(const gchar* filename);
+const gchar* guppi_glade_path(const gchar* filename);
 const gchar* gnome_guile_repl_path(void);
 
 #endif /* _INC_GUPPI_PATHS_H */
 
-/* $Id: guppi-paths.h,v 1.2 2000/01/17 21:38:34 trow Exp $ */
+/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */
