@@ -1,4 +1,4 @@
-/* $Id: guppi-splash.c,v 1.2 2000/02/11 07:25:39 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.3 2000/04/21 23:22:45 trow Exp $ */
 
 /*
  * guppi-splash.c
@@ -77,6 +77,20 @@ destroy_timeout(gpointer user_data)
   return FALSE;
 }
 
+static void
+set_style(GtkWidget* w, gpointer foo)
+{
+  GtkStyle* style;
+  GdkColor bg = { 0xaedaee, 0xae00, 0xda00, 0xee00};
+  GdkColor fg = { 0x0000ff, 0x0000, 0x0000, 0xffff};
+
+  style = gtk_style_copy(gtk_widget_get_style(w));
+  style->bg[0] = bg;
+  style->fg[0] = fg;
+  gtk_widget_set_style(w, style);
+  gtk_widget_set_style(GTK_WIDGET(foo), style);
+}
+
 void
 guppi_splash_create(void)
 {
@@ -91,6 +105,7 @@ guppi_splash_create(void)
   gtk_window_set_position(GTK_WINDOW(splash), GTK_WIN_POS_CENTER);
   gtk_window_set_policy(GTK_WINDOW(splash), FALSE, FALSE, FALSE);
 
+
   buffer = g_strdup_printf(_("Welcome to Guppi %s"), VERSION);
   gtk_window_set_title(GTK_WINDOW(splash), buffer);
   g_free(buffer);
@@ -100,9 +115,18 @@ guppi_splash_create(void)
   pixmap = gnome_pixmap_new_from_file(guppi_logo_graphic_path());
 
   splash_label = gtk_label_new("");
+  gtk_label_set_line_wrap(GTK_LABEL(splash_label), TRUE);
+  gtk_label_set_justify(GTK_LABEL(splash_label), GTK_JUSTIFY_CENTER);
+
+  /* We change the style and adjust the color scheme upon
+     realization... */
+  gtk_signal_connect(GTK_OBJECT(splash),
+		     "realize",
+		     GTK_SIGNAL_FUNC(set_style),
+		     splash_label);
 
   gtk_box_pack_start(GTK_BOX(vbox), pixmap, TRUE, TRUE, 1);
-  gtk_box_pack_end(GTK_BOX(vbox), splash_label, TRUE, FALSE, 1);
+  gtk_box_pack_end(GTK_BOX(vbox), splash_label, TRUE, TRUE, 1);
   gtk_container_add(GTK_CONTAINER(splash), vbox);
 
   gtk_widget_show_all(splash);
@@ -115,9 +139,16 @@ guppi_splash_create(void)
 void
 guppi_splash_destroy(void)
 {
+  gchar* buffer;
+
   g_return_if_fail(splash != NULL);
 
-  guppi_splash_message(_("Visit us at http://www.gnome.org/guppi"));
+  buffer = g_strdup_printf(_("Visit us at %s"), "http://www.gnome.org/guppi");
+
+  guppi_splash_message(buffer);
+
+  g_free(buffer);
+
   please_destroy_splash = TRUE;
 }
 
@@ -129,6 +160,7 @@ guppi_splash_message(const gchar* text)
   if (splash) {
     gtk_catchup();
     gtk_label_set_text(GTK_LABEL(splash_label), (gchar*)text);
+
   }
   g_message(text);
 
@@ -138,4 +170,4 @@ guppi_splash_message(const gchar* text)
 }
 
 
-/* $Id: guppi-splash.c,v 1.2 2000/02/11 07:25:39 trow Exp $ */
+/* $Id: guppi-splash.c,v 1.3 2000/04/21 23:22:45 trow Exp $ */
