@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-stream-preview.c,v 1.2 2000/02/21 18:26:45 trow Exp $ */
+/* $Id: guppi-stream-preview.c,v 1.3 2000/04/25 13:57:11 trow Exp $ */
 
 /*
  * guppi-stream-preview.c
@@ -623,9 +623,9 @@ guppi_stream_preview_construct(GuppiStreamPreview* gsp)
                     (GtkAttachOptions) (GTK_EXPAND),
                     (GtkAttachOptions) (0), 0, 0);
   gtk_widget_set_usize (eol_combo, 75, -2);
-  eol_combo_items = g_list_append (eol_combo_items, _("#"));
-  eol_combo_items = g_list_append (eol_combo_items, _("//"));
-  eol_combo_items = g_list_append (eol_combo_items, _(";"));
+  eol_combo_items = g_list_append (eol_combo_items, "#");
+  eol_combo_items = g_list_append (eol_combo_items, "//");
+  eol_combo_items = g_list_append (eol_combo_items, ";");
   eol_combo_items = g_list_append (eol_combo_items, _("<none>"));
   gtk_combo_set_popdown_strings (GTK_COMBO (eol_combo), eol_combo_items);
   g_list_free (eol_combo_items);
@@ -635,7 +635,7 @@ guppi_stream_preview_construct(GuppiStreamPreview* gsp)
 
   combo_entry6 = GTK_COMBO (eol_combo)->entry;
   gtk_widget_show (combo_entry6);
-  gtk_entry_set_text (GTK_ENTRY (combo_entry6), _("#"));
+  gtk_entry_set_text (GTK_ENTRY (combo_entry6), "#");
 
   begin_ml_combo = gtk_combo_new ();
   gtk_widget_show (begin_ml_combo);
@@ -644,9 +644,9 @@ guppi_stream_preview_construct(GuppiStreamPreview* gsp)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_widget_set_usize (begin_ml_combo, 75, -2);
   begin_ml_combo_items = g_list_append (begin_ml_combo_items, _("<none>"));
-  begin_ml_combo_items = g_list_append (begin_ml_combo_items, _("/*"));
-  begin_ml_combo_items = g_list_append (begin_ml_combo_items, _("<"));
-  begin_ml_combo_items = g_list_append (begin_ml_combo_items, _("(*"));
+  begin_ml_combo_items = g_list_append (begin_ml_combo_items, "/*");
+  begin_ml_combo_items = g_list_append (begin_ml_combo_items, "<");
+  begin_ml_combo_items = g_list_append (begin_ml_combo_items, "(*");
   gtk_combo_set_popdown_strings (GTK_COMBO (begin_ml_combo), begin_ml_combo_items);
   g_list_free (begin_ml_combo_items);
 
@@ -664,9 +664,9 @@ guppi_stream_preview_construct(GuppiStreamPreview* gsp)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_widget_set_usize (end_ml_combo, 75, -2);
   end_ml_combo_items = g_list_append (end_ml_combo_items, _("<none>"));
-  end_ml_combo_items = g_list_append (end_ml_combo_items, _("*/"));
-  end_ml_combo_items = g_list_append (end_ml_combo_items, _(">"));
-  end_ml_combo_items = g_list_append (end_ml_combo_items, _("*)"));
+  end_ml_combo_items = g_list_append (end_ml_combo_items, "*/");
+  end_ml_combo_items = g_list_append (end_ml_combo_items, ">");
+  end_ml_combo_items = g_list_append (end_ml_combo_items, "*)");
   gtk_combo_set_popdown_strings (GTK_COMBO (end_ml_combo), end_ml_combo_items);
   g_list_free (end_ml_combo_items);
 
@@ -848,4 +848,4 @@ guppi_stream_preview_glade_custom_func(gchar* name,
 
 
 
-/* $Id: guppi-stream-preview.c,v 1.2 2000/02/21 18:26:45 trow Exp $ */
+/* $Id: guppi-stream-preview.c,v 1.3 2000/04/25 13:57:11 trow Exp $ */
